(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     20632,        551]
NotebookOptionsPosition[     18554,        479]
NotebookOutlinePosition[     19185,        504]
CellTagsIndexPosition[     19100,        499]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell["Load the LGSBloch package", "Text"],

Cell[BoxData[
 RowBox[{"SetDirectory", "[", 
  RowBox[{"NotebookDirectory", "[", "]"}], "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"<<", "LGSBloch`"}]], "Input"],

Cell["\<\
Generate the system of equations for the Na D2 line. (This can take a few \
minutes.)\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"NaD2LGS", "=", 
   RowBox[{"GenerateLGSSystem", "[", "]"}]}], ";"}]], "Input"],

Cell["\<\
 If you like, you can save the generated data to a file, so that you can \
recall it in the next Mathematica session with \
Get[ToFileName[NotebookDirectory[],\[CloseCurlyDoubleQuote]NaD2LGS.mx\
\[CloseCurlyDoubleQuote]]], without having to compute it again.\
\>", "Text"],

Cell[BoxData[
 RowBox[{"Save", "[", 
  RowBox[{
   RowBox[{"ToFileName", "[", 
    RowBox[{
     RowBox[{"NotebookDirectory", "[", "]"}], ",", "\"\<NaD2LGS.mx\>\""}], 
    "]"}], ",", "NaD2LGS"}], "]"}]], "Input"],

Cell[TextData[StyleBox["Comparison of cw excitation efficiency between cw and \
pulsed simulation routines\nRon Holzloehner, 01Dec11\n\n\
Let\[CloseCurlyQuote]s first set the environmental and laser parameters.",
 FontFamily->"Verdana"]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"opt1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"IMeso", "\[Rule]", "78.48"}], ",", 
     RowBox[{"RepumpFraction", "\[Rule]", "0.1"}], ",", 
     RowBox[{"LightPolarization", "\[Rule]", "1."}], ",", 
     RowBox[{"BG", "\[Rule]", "0.4662"}], ",", 
     RowBox[{"MagneticZenith", "\[Rule]", 
      RowBox[{
       RowBox[{"61.0", "*", 
        RowBox[{"\[Pi]", "/", "180.0"}]}], "+", 
       RowBox[{"\[Pi]", "/", "2.0"}]}]}], ",", 
     RowBox[{"MagneticAzimuth", "\[Rule]", 
      RowBox[{"14.0", "*", 
       RowBox[{"\[Pi]", "/", "180.0"}]}]}], ",", 
     RowBox[{"FWHMbw", "\[Rule]", "0."}], ",", 
     RowBox[{"Zenith", "\[Rule]", "0."}], ",", 
     RowBox[{"Htele", "\[Rule]", "1284."}], ",", 
     RowBox[{"DLT", "\[Rule]", "0.2"}], ",", 
     RowBox[{"\[Mu]LT", "\[Rule]", "1."}], ",", "\[IndentingNewLine]", 
     RowBox[{"Ta", "\[Rule]", "0.89"}], ",", 
     RowBox[{"HNa", "\[Rule]", 
      RowBox[{"95000.0", "+", "1284.0"}]}], ",", 
     RowBox[{"PLaunch", "\[Rule]", "49.9602"}]}], "}"}]}], ";"}]], "Input"],

Cell[TextData[StyleBox["Here\[CloseCurlyQuote]s the specific mesospheric \
return flux at I=IMeso=78.48 W/m^2",
 FontFamily->"Verdana"]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PsiIMeso", "=", 
  RowBox[{"PsiMeso", "[", 
   RowBox[{"NaD2LGS", ",", "opt1"}], "]"}]}]], "Input"],

Cell[BoxData["277.2708557116478`"], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["Set sodium coumn abundance [atoms/m^2]",
 FontFamily->"Verdana"]], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cNa", "=", "4.0*^13"}], ";"}]], "Input"],

Cell[TextData[StyleBox["Mesospheric spot FWHM and area [m]:",
 FontFamily->"Verdana"]], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"mySpotFWHM", "=", 
    RowBox[{"2", "*", "0.25"}]}], ";"}], "\[IndentingNewLine]", "  ", 
  RowBox[{"(*", " ", 
   RowBox[{
   "w2FWHM", " ", "is", " ", "the", " ", "conversion", " ", "factor", " ", 
    "from", " ", "waist", " ", "radius", " ", "to", " ", "FWHM", " ", "of", 
    " ", "a", " ", "Gaussian", " ", "beam"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"w2FWHM", "=", 
    RowBox[{"Sqrt", "[", 
     RowBox[{"2.0", "*", 
      RowBox[{"Log", "[", "2", "]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"w", " ", "is", " ", "the", " ", 
    RowBox[{"1", "/", 
     RowBox[{"e", "^", "2"}]}], " ", "radius", " ", "in", " ", "intensity"}], 
   " ", "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"w", "=", 
    RowBox[{"mySpotFWHM", "/", "w2FWHM"}]}], ";"}], "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{"Effective", " ", "spot", " ", "area"}], " ", 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"mySpotArea", "=", 
   RowBox[{"\[Pi]", " ", 
    RowBox[{"w", "^", "2"}]}]}], ";"}]}], "Input"],

Cell[TextData[StyleBox["\nCrude estimate of the expected return flux \
\[CapitalPhi] on the ground [W/m^2]\nFor the formula, see e.g. Eq(6) in \
Holzloehner et al., A&A (2010)\nNote that this assumes a sodium centroid of \
95km + 1.28km telescope altitude = 96.28 km which is quite high.",
 FontFamily->"Verdana"]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Phi1", "=", 
  RowBox[{
   RowBox[{"PsiIMeso", "*", "IMeso", "*", "cNa", "*", "mySpotArea", "*", 
    RowBox[{"Ta", "/", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"HNa", "-", "Htele"}], ")"}], "^", "2"}]}]}], "/.", 
   "opt1"}]}]], "Input"],

Cell[BoxData["4.862956997349471`*^7"], "Output"]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["To obtain a realistic value of  \[CapitalPhi], we have to sample \
the return flux at a few irradiance levels. We compute a repository of such \
samples. By setting LaserSpotMesoFWHM directly, we bypass the computation of \
the mesospheric irradiances through DLT and MsqrLT etc.:",
  FontFamily->"Verdana"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"optBeamRep", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"LaserSpotMesoFWHM", "\[Rule]", "mySpotFWHM"}], ",", 
     RowBox[{"NSamples", "\[Rule]", "12"}]}], "}"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"rep1", "=", 
  RowBox[{"BeamRepository", "[", 
   RowBox[{"NaD2LGS", ",", "opt1", ",", "optBeamRep"}], "]"}]}]}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"InterpolatingFunction", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"0.`", ",", "156.96750164103025`"}], "}"}], "}"}], 
      ",", "\<\"<>\"\>"}], "]"}],
    False,
    Editable->False], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"0.`", ",", "0.`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"0.35`", ",", "100.75553739567093`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1.705995685203725`", ",", "613.5367410957523`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5.638383172294527`", ",", "2250.9174121651185`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"12.147162461272407`", ",", "4809.074521965893`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"21.23233355213737`", ",", "7947.872571288276`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"32.89389644488941`", ",", "11415.146835083797`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"47.13185113952852`", ",", "15056.157307333995`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"63.94619763605471`", ",", "18810.111720958263`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"83.33693593446797`", ",", "22694.73256235553`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"105.30406603476833`", ",", "26714.053720142492`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"129.84758793695573`", ",", "30837.27519588496`"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"156.96750164103025`", ",", "35172.656522994264`"}], "}"}]}], 
    "}"}], ",", "156.96750164103025`", ",", "0.5`"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["The vector of irradiance samples goes to 156.968 W/m^2 which is \
twice as much as the value of IMeso:",
  FontFamily->"Verdana"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"156.96", "/", "IMeso"}], "/.", "opt1"}]], "Input"],

Cell[BoxData["2.`"], "Output"]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["The routine Sce performs the integration across the Gaussian beam:",
  FontFamily->"Verdana"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "Sce"}]], "Input"],

Cell[BoxData[
 StyleBox["\<\"Compute beam figure of merit \
\\!\\(\\*FormBox[SubscriptBox[\\(s\\), \\(ce\\)],\\nTraditionalForm]\\). Note \
that the following options may be changed from their values when \
BeamRepository[] was called, unless the peak intensity exceeds that of the \
interpolating function:\\n\\tPLaunch: Launched power [W]\\n\\tZenith: Zenith \
angle [rad]   (note that MagneticZenith and MagneticAzimuth cannot be \
changed!)\\n\\tHNa: Altitude of sodium centroid above sea level \
[m]\\n\\tHtele: Altitude of launch telescope above sea level [m]\\n\\tDLT: \
Launch telescope aperture [m]\\n\\t\[Mu]LT: Ratio of DLT to \\!\\(\\*FormBox[\
\\(1/\\*SuperscriptBox[\\(e\\), \\(2\\)]\\),\\nTraditionalForm]\\) lauch beam \
intensity diameter (not radius!), see Yura, Eq.(2.7)\\n\\tMsqrLT:  Effective \
\\!\\(\\*FormBox[SuperscriptBox[\\(M\\), \\(2\\)],\\nTraditionalForm]\\) beam \
quality factor out of the launch telescope, also taking into account the \
effect of speckles\\n\\tLaserSpotMesoFWHM: Mesospheric FWHM spot size [m]. If \
this option is set to a nonzero value, DLT and \[Mu]LT are not used to \
compute the mesospheric irradiance.\\n\\nOutput values:\\n\\tsceOut: Merit \
parameter \\!\\(\\*FormBox[SubscriptBox[\\(s\\), \
\\(ce\\)],\\nTraditionalForm]\\)\\!\\(\\*\\nStyleBox[\\\" \\\",\\nFontSlant->\
\\\"Italic\\\"]\\)[ph/s/W/(atom/m^2)]\\n\\tGroundInt: Integrated flux on the \
ground [ph/s/atom]\\n\\tFluxMesoInt: Integrated flux in the mesosphere \
[ph*m^2/s/sr/atom]\\n\\tFWHMSpeckle: Instantaneous laser spot size in the \
mesosphere (central speckle) [m]\\n\\tFWHM2mom: Return light spot size based \
on second moment [m]\\n\\tIMesoMax: Peak mesospheric laser light intensity \
[W/m^2]\"\>", "MSG"]], "Print", "PrintUsage",
 CellTags->"Info3618303114-1163771"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sce1", "=", 
  RowBox[{"Sce", "[", 
   RowBox[{"opt1", ",", 
    RowBox[{"rep1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
    ",", "optBeamRep"}], "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "295.96690973994345`", ",", "1.2977771669540279`*^-6", ",", 
   "13160.043743550676`", ",", "0.5`", ",", "0.5508564593251178`", ",", 
   "156.96750164103025`", ",", "LGSBloch`Private`fitFunction$59517", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
     "LGSBloch`Private`Psi0$59517", "\[Rule]", "43522.358561169385`"}], ",", 
     RowBox[{"LGSBloch`Private`I0$59517", "\[Rule]", "124.92395014509131`"}], 
     ",", 
     RowBox[{"LGSBloch`Private`c$59517", "\[Rule]", "0.9171198806563587`"}]}],
     "}"}], ",", "0.009557986181447256`"}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["Multiply GroundInt (2nd return value in the above results list) by \
the column abundance to obtain the flux on the ground in ph/s/m^2:",
  FontFamily->"Verdana"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Phi2", "=", 
  RowBox[{
   RowBox[{"sce1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
   "*", "cNa"}]}]], "Input"],

Cell[BoxData["5.1911086678161114`*^7"], "Output"]
}, Open  ]],

Cell[TextData[{
 "\n",
 StyleBox["Note that phi2 also agrees quite well with Phi1 further above. ",
  FontFamily->"Verdana"],
 "\n\n",
 StyleBox["We can compare these values to Rachel\[CloseCurlyQuote]s results \
from StepPulseFlux[] at 50W:\nAs we can see, there\[CloseCurlyQuote]s an \
agreement on both \[CapitalPhi]=52 Mph/s/m^2 and sce=296 ph/s/W/(atom/m^2). ",
  FontFamily->"Verdana"],
 "\n"
}], "Text"],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{}, {}, 
        {RGBColor[0, 0, 1], Thickness[0.003], LineBox[CompressedData["
1:eJxdkW1I00Ecx6eWmYR7oZn5sFqmpUvndM6pm/vO/55dMjQdRREZMzSGSVrK
1hQyQ7NA8oVKZmZSDmtGRoliFJZFqZT0oFKJpRVms1zQHsxs3asOjuO4u9/v
8/0cM68oS+dJo9ESVubf9f/heuvXarBbRaM7KcpOd4n+7ZdFynMxpSatL05E
ZtwJda6BPrqjO8/DH//O6bjQlMjxuRSEAVUBNe/0R2Ct/wZ9AAMm9/0NyNh/
95HPLSYEnjEstSME7bRy/S/1VvJ+Ey6zaXUj45F4t7esJsfFRI5urObjnihS
LxzfmfynyucsXOTvWapyRqBRPesxIYwlPNvQ+2a6rUMTh30BguIeRxR2n9fd
DDFxIHT3Y8F25Qa7/mo8QhfCZj7YY6CrqKwUDSeQ/mxE1uUE77Zy8W2moqvG
FYegxddPfP14hIeD/LVVncaoJIyMHclnuuLR0HRh+oWYT/gSoJC/k8Zqk3Hj
/oHNvU4ulOOrHnUVpKDFzZuI2+81kwXlqThryZrQOHn4NS15aaoWEP4k6LxL
GF71QuhbqIbPDj66tkhL1zWlkTzJCJ2aDLFcFGHnGW5mpSMFwZ8O05Y1IPlS
sfAstPjUc2BHeYRPkEOAo9l9iYsaMckrhJkxuE0zKsa6Q4EPLPY0sCTvLe3q
dJJfhCTuvVHb43QcM3sNtBsB8QtXtEpCER/AVOGwn3mAwkr45iKjGFzu57Jg
voT4EWMwxRzW1i1BbqPteKoxHdVzDXpqu5T4SseAXdDs3SqFjD6/a42RgtbZ
12wNkBF/FKIze9hetTLwqmc4YwYJvtbZZqW/Zbju9inBrPUho79Yjoilv8BS
TO23+hR+lBO/Uhy8Vno9O1eB9SWv5goNMpzeuHneOKQgvmWg/xg6+SVJidVz
I495Bjnmw8p8W64qiX856OF59uZAFX4eGOrwNCiQX9HVOVulIv+hQL+YoT35
Q4U/y+VsdQ==
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       BaseStyle->{FontFamily -> "Verdana", 12},
       Frame->True,
       FrameLabel->{
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\nStyleBox[\\\"P\\\",\\nFontSlant->\\\"\
Italic\\\"], \\\"launch\\\"]\\)  [W]\"", TraditionalForm], 
         FormBox[
         "\"\[CapitalPhi]  [\\!\\(\\*SuperscriptBox[\\\"10\\\", \\\"6\\\"]\\) \
ph/s/\\!\\(\\*SuperscriptBox[\\\"m\\\", \\\"2\\\"]\\)]\"", TraditionalForm]},
       GridLines->Automatic,
       ImageSize->288,
       PlotLabel->FormBox[
         StyleBox[
         "\"Return Flux on Ground at \
\\!\\(\\*SubscriptBox[\\nStyleBox[\\\"C\\\",\\nFontSlant->\\\"Italic\\\"], \\\
\"Na\\\"]\\) = 4.\[Times]\\!\\(\\*SuperscriptBox[\\\"10\\\", \\\"13\\\"]\\) \
atoms/\\!\\(\\*SuperscriptBox[\\\"m\\\", \\\"2\\\"]\\)\"", FontFamily -> 
          "Verdana", FontSize -> 12, StripOnInput -> False], TraditionalForm],
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {153.6, -94.93002067198384},
       ImageScaled[{0.5, 0.5}], {288, 177.9937887599697}], InsetBox[
      GraphicsBox[{{}, {}, 
        {RGBColor[0, 0, 1], Thickness[0.003], LineBox[CompressedData["
1:eJwtkX0s1HEcx3W3pBJbF2pUno7ykMhTncub8/yQJqkRo1aN6Pwe7s51Rw1r
042akBQaY83EejCrpNEapR0NWSo2uqV5yFZxD6yk7x/fffbd9/v5fl7v19fu
tDj+LMfIyMhrdf2ry1/M6hS6H4HvsoezVPlK/N//CfTVvDWNfHkJeU7RHTaG
DeiPfzxr/FxOzs3x5hN10HydHF1RGaI5Aw+lTXX2e8S5yF+7b4V6/kOXlEUZ
AjjurjF6axxyX0waKJWR/t3o7s34OHpAhvFTucXHl+2QyMuIUU5KyXsOGJJN
uHZUSVHrn7RSZODDJXr+5/bjUsLjjFynFrebllKkbAugnuj3wrLz5NzJzxII
1+a5YiRZ59HfKIHNwk7NlM4d9Q06ThYtIfM9oPK+NT0SJMG85nJL8fJ+8BIm
x9p5EsLjCbH10sbebyzUQznn7Ja9kO9w+9XAC5bwHYDQati5roJFa3e67VOD
NzRCi4ubxSxq1nh9ENLGK1uIZFHSFj921OALbmptjIcTS/j9sHCsL6SFyyK7
RlQ+rffH8My1C3GTDMlzEGZpahm3h0GsyvvIFf0heAqkivZ6huQTwPHZT1VC
EQM3Od9kuz4APq8Fl96fY0heIbintZW7ohiYnrfsadMdRhFz54rHPobkD4R1
rFCn3cpA2sztalACqVn8VzlamvgAyhKUBSXjNFbDV4uVQYj/lN0Q9pomfoLw
JXlWVN5CI7Hql0ygDIZ8JM9WXE4TX8GYD6wsHFTSCDOfS9igFCHTfoffo7M0
8SdCc3WrzCyOhu9VjeeQIgSsqun7hD+NB2s+QxCQtv+6nQMN/so/4FCkneh4
qd5CE7+hsOUIbKe0FCzYDzOZijDcMy64m/SVIr7DYJKxKd1zkML6GXWfryIc
UUu1I2c6KeI/HPab86rm71P4nd7byFFEwHFUK1dXUOQ/IlC3ciPXqJDCX2lQ
dpo=
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0, 0},
       BaseStyle->{FontFamily -> "Verdana", 12},
       Frame->True,
       FrameLabel->{
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\nStyleBox[\\\"P\\\",\\nFontSlant->\\\"\
Italic\\\"], \\\"launch\\\"]\\)  [W]\"", TraditionalForm], 
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\nStyleBox[\\\"s\\\",\\nFontSlant->\\\"\
Italic\\\"], \\\"ce\\\"]\\)  \
[ph/s/W/(atoms/\\!\\(\\*SuperscriptBox[\\\"m\\\", \\\"2\\\"]\\))]\"", 
          TraditionalForm]},
       GridLines->Automatic,
       ImageSize->288,
       PlotLabel->FormBox[
         StyleBox[
         "\"Laser format efficiency \\!\\(\\*SubscriptBox[\\nStyleBox[\\\"s\\\
\",\\nFontSlant->\\\"Italic\\\"], \\\"ce\\\"]\\) (\[Theta]=151.6 deg)\"", 
          FontFamily -> "Verdana", FontSize -> 12, StripOnInput -> False], 
         TraditionalForm],
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {460.79999999999995`, -94.93002067198384},
       ImageScaled[{0.5, 0.5}], {288, 177.9937887599697}]}, {InsetBox[
      GraphicsBox[{{}, {}, 
        {RGBColor[0, 0, 1], Thickness[0.003], LineBox[CompressedData["
1:eJw1kXss1WEYx11myoqd3IoTTpJczuLgkNvzcNzSIZcThRqZqCm15VLnUAuZ
sLS1VUSNtFY4m1qxcebyB8uJYmoh/V52TI7jsvHHuajQ7/fHu2fv3vd5n8/3
83Iu5CVkGejp6fG21nbV/TR9LlavgHtW92CKjIL/+79Q3zDhXzJAQfGRkx/Z
WmMMl+fnJg8x52bIe2vXvSmnQBZ9SaDSmiP3U2Kk5CsFJTv3rXGkXNH2Y4KC
QAOum1Bji/t6ajJtJpl+e4y6JW0KmaFgJq2o8rSOg53a3tn4WeY9RyzMcT0Q
M09Bo1/KZpnWCXmZc7+8FxkeZ0z9vVRjskzBOYvA6+81LuhQ1BA5ukZB0M48
N+SPKXeXbVDAXj2omFNzsetLWYeLmpl/DKumZEZ9OgqWFbdbK3UeKFuzfBet
R2geT5yvaDwzaEhgZPzaRY6Ohx3POst9jQnN54UyF5+eehMC7X0ZDl1ab2w1
YxWu7yXQsMPrg+nVM5xQFoEaacJknJaPC2UrjuUWhOb3xfhDsdM91gSuNAge
LWj8ULlY07xkQ+g8xzHbqljOsiMQU+Ude0fjj8Gs7pdcDqHzBWDvJOTjYQLu
N5127dcEop2i/260M6HzBmFx6VFToSuBPdlW/VJ1MM4WfBaFcwmdH9BidKaW
70Gg4I2hrFmCSE08VNt7EdoHoj8na0CfT2ArfF2eJARF1SKHaT/GTwg+6N6F
0gACSU/WCwMkobg2rh8nDmZ8heKwqkeMIQQizFQiY4kAT6mmlv4IGH8C/G4a
MPwhggD/nsJzXByGikbroJwTBNp2fIZhqKtTtrmQgNPmNnA4tlx9ldsZy/gN
R1thaV5yPAHLG9+Ul8UR2KRMq11NZHxH4H3hi+XSJAJGypEhvjgSY9Mfv2ad
ZfxHInuyaOppKoGNjMEWA3EUVowVNLPPM/8Rhe3Jctu6dAL/AHLBjGE=
          "]]}},
       AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
       Axes->True,
       AxesOrigin->{0., 0.523},
       BaseStyle->{FontFamily -> "Verdana", 12},
       Frame->True,
       FrameLabel->{
         FormBox[
         "\"\\!\\(\\*SubscriptBox[\\nStyleBox[\\\"P\\\",\\nFontSlant->\\\"\
Italic\\\"], \\\"launch\\\"]\\)  [W]\"", TraditionalForm], 
         FormBox["\"FWHM  [m]\"", TraditionalForm]},
       GridLines->Automatic,
       ImageSize->288,
       PlotLabel->FormBox[
         StyleBox[
         "\"Mesospheric Return Spot Size (2nd moment)\"", FontFamily -> 
          "Verdana", FontSize -> 12, StripOnInput -> False], TraditionalForm],
       PlotRange->{All, All},
       PlotRangeClipping->True,
       PlotRangePadding->{Automatic, Automatic}], {153.6, -284.79006201595155`},
       ImageScaled[{0.5, 0.5}], {288, 177.9937887599697}], 
     InsetBox["", {460.79999999999995`, -284.79006201595155`}, {
      Center, Center}, {287.99999999999994`, 177.9937887599697}]}}, {}},
  ContentSelectable->True,
  ImageSize->{626.4, 391.72008268793536`},
  PlotRangePadding->{6, 5}]], "Print"]
},
WindowSize->{720, 852},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
ShowSelection->True,
TrackCellChangeTimes->False,
PrivateNotebookOptions -> {
 "VersionedStylesheet" -> {"Default.nb"[8.] -> True}},
FrontEndVersion->"7.0 for Microsoft Windows (64-bit) (February 18, 2009)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3618303114-1163771"->{
  Cell[8221, 258, 1797, 25, 380, "Print",
   CellTags->"Info3618303114-1163771"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3618303114-1163771", 18994, 493}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[557, 20, 41, 0, 29, "Text"],
Cell[601, 22, 104, 2, 31, "Input"],
Cell[708, 26, 53, 1, 31, "Input"],
Cell[764, 29, 109, 3, 29, "Text"],
Cell[876, 34, 113, 3, 31, "Input"],
Cell[992, 39, 282, 5, 47, "Text"],
Cell[1277, 46, 213, 6, 31, "Input"],
Cell[1493, 54, 246, 3, 79, "Text"],
Cell[1742, 59, 1065, 25, 92, "Input"],
Cell[2810, 86, 145, 2, 28, "Text"],
Cell[CellGroupData[{
Cell[2980, 92, 123, 3, 31, "Input"],
Cell[3106, 97, 45, 0, 30, "Output"]
}, Open  ]],
Cell[3166, 100, 98, 1, 28, "Text"],
Cell[3267, 103, 75, 2, 31, "Input"],
Cell[3345, 107, 95, 1, 28, "Text"],
Cell[3443, 110, 1157, 32, 152, "Input"],
Cell[4603, 144, 323, 4, 96, "Text"],
Cell[CellGroupData[{
Cell[4951, 152, 272, 8, 31, "Input"],
Cell[5226, 162, 48, 0, 30, "Output"]
}, Open  ]],
Cell[5289, 165, 353, 7, 80, "Text"],
Cell[CellGroupData[{
Cell[5667, 176, 373, 10, 45, "Input"],
Cell[6043, 188, 1617, 40, 90, "Output"]
}, Open  ]],
Cell[7675, 231, 175, 5, 64, "Text"],
Cell[CellGroupData[{
Cell[7875, 240, 85, 2, 29, "Input"],
Cell[7963, 244, 30, 0, 28, "Output"]
}, Open  ]],
Cell[8008, 247, 139, 4, 45, "Text"],
Cell[CellGroupData[{
Cell[8172, 255, 46, 1, 28, "Input"],
Cell[8221, 258, 1797, 25, 380, "Print",
 CellTags->"Info3618303114-1163771"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10055, 288, 205, 5, 29, "Input"],
Cell[10263, 295, 603, 13, 83, "Output"]
}, Open  ]],
Cell[10881, 311, 208, 5, 64, "Text"],
Cell[CellGroupData[{
Cell[11114, 320, 152, 4, 28, "Input"],
Cell[11269, 326, 49, 0, 30, "Output"]
}, Open  ]],
Cell[11333, 329, 410, 10, 113, "Text"],
Cell[11746, 341, 6804, 136, 400, "Print"]
}
]
*)

(* End of internal cache information *)
